@@ -18,6 +18,8 @@ use Rewire::Engine;
 
 with 'Data::Object::Role::Buildable';
 
+our $VERSION = '0.03'; # VERSION
+
 # BUILD
 
 fun build_self($self, $args) {
@@ -490,7 +492,36 @@ service named but where the arguments are provided ad-hoc.
 
   # given: synopsis
 
-  $rewire->process('tempfile', '/tmp/rewire.txt');
+  $rewire->process('tempfile', 'rewire.tmp');
+
+=back
+
+=over 4
+
+=item process example #2
+
+  use Rewire;
+
+  my $metadata = {
+    logfile => '/var/log/rewire.log',
+  };
+
+  my $services = {
+    mojo_log => {
+      package => 'Mojo/Log',
+      argument => { '$metadata' => 'logfile' },
+    }
+  };
+
+  my $rewire = Rewire->new(
+    services => $services,
+    metadata => $metadata
+  );
+
+  $rewire->process('mojo_log', {
+    level => 'fatal',
+    path => { '$metadata' => 'logfile' }
+  });
 
 =back
 
